AppNameLocalizationConfig class

Parsed configuration from a Flutter project's pubspec.yaml.

Constructors

AppNameLocalizationConfig({required String defaultName, Map<String, String>? locales})
AppNameLocalizationConfig.fromYamlString(String yamlSource)
factory

Properties

defaultName String
The default Android app name written to values/strings.xml.
final
hashCode int
The hash code for this object.
no setterinherited
locales Map<String, String>
Additional Android resource qualifiers mapped to localized app names.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited