AppNameLocalizer class

Updates Android strings.xml resources from flutter_app_name_localization.

Constructors

AppNameLocalizer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

localize({required String pubspecPath, bool validateManifest = true}) AppNameLocalizationResult