AppNameLocalizationResult class
The result of updating localized Android app names for a Flutter project.
Constructors
-
AppNameLocalizationResult({required String pubspecPath, required String projectDirectory, required AppNameLocalizationConfig config, required List<
String> updatedFiles, required List<String> warnings})
Properties
- config → AppNameLocalizationConfig
-
The parsed localization configuration.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectDirectory → String
-
Absolute path to the Flutter project directory.
final
- pubspecPath → String
-
Absolute path to the parsed
pubspec.yaml.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
updatedFiles
→ List<
String> -
Absolute paths to the
strings.xmlfiles that were updated.final -
warnings
→ List<
String> -
Non-fatal warnings discovered while localizing.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited